__package__ = 'dsocli.provider.parameter.aws.ssm.v1'
from .main import get_default_spec
from .main import AwsSsmParameterProvider
